Unreplicated designs using the sparse allocation approach
Source:R/fct_sparse_allocation.R
sparse_allocation.RdUnreplicated designs using the sparse allocation approach
Usage
sparse_allocation(
lines,
nrows,
ncols,
l,
planter = "serpentine",
plotNumber,
copies_per_entry,
checks = NULL,
exptName = NULL,
locationNames,
sparse_list,
seed,
data = NULL,
year = NULL,
checksPercent = NULL
)Arguments
- lines
Number of genotypes, experimental lines or treatments.
- nrows
Number of rows in the field.
- ncols
Number of columns in the field.
- l
Number of locations or sites. By default
l = 1.- planter
Option for
serpentineorcartesianplot arrangement. By defaultplanter = 'serpentine'.- plotNumber
Numeric vector with the starting plot number for each location. By default
plotNumber = 101.- copies_per_entry
Number of copies per plant. When design is
sparsethencopies_per_entry<l- checks
Number of genotypes checks.
- exptName
(optional) Name of the experiment.
- locationNames
(optional) Names each location.
- sparse_list
(optional) A class "Sparse" object generated by
do_optim()function.- seed
(optional) Real number that specifies the starting seed to obtain reproducible designs.
- data
(optional) Data frame with 2 columns:
ENTRY | NAME. ENTRY must be numeric.- year
(optional) Year recorded in the
YEARcolumn of the field book. By default the current year.- checksPercent
(optional) Percentage of checks in each location, one of the options available for the field. By default the last (largest) option.
Value
A list with eight elements.
infoDesignis a list with information on the design parameters.layoutRandomis a list with the randomization layout of each location.plotsNumberis a list with the plot number layout of each location.data_entryis a data frame with the data input.fieldBookis a data frame with the field book of all locations.list_locsis a list with each location list of entries.allocationis a matrix with the allocation of treatments.size_locationsis a named vector with the number of lines allocated to each location.
Reproducibility
The result records effective inputs and the resolved seed in
metadata$parameters. Under the same package versions and RNG
settings, rebuild a result x with
do.call(sparse_allocation, x$metadata$parameters).
References
Edmondson, R.N. Multi-level Block Designs for Comparative Experiments. JABES 25, 500–522 (2020). https://doi.org/10.1007/s13253-020-00416-0
Examples
sparse <- sparse_allocation(
lines = 120,
l = 4,
copies_per_entry = 3,
checks = 4,
locationNames = c("LOC1", "LOC2", "LOC3", "LOC4"),
seed = 1234
)